@echo off
call arithmetic.bat init
:: *** Examples for arithmetic.bat v1.1 ***
:: Call the file here once to initialize and load all the macros.
:: This must be done before enabling delayed expansion.
:: Note that you should never override any of its macros or local
:: variables that begin with '_$'.
:: Also, while the script allows for larger numbers, there
:: are still limitations in the number of digits each operation can handle.
:: See the intro section in arithmetic.bat for details.

::====================================================================
echo.
echo ------ Testing Integer Operations ------
set "numA=458078705775434" & set "numB=75647435645635"
%@addi% "%numA%" "%numB%" "result"
echo @addi: %numA% + %numB% = %result%

set "numA=300800012" & set "numB=9250000230587002"
%@subi% "%numA%" "%numB%" "result"
echo @subi: %numA% - %numB% = %result%

set "numA=9999999999999999" & set "numB=9999999999999999"
%@multi% "%numA%" "%numB%" "result"
echo @multi: %numA% X %numB% = %result%

set "numA=-123456781234567812345678" & set "numB=82400090"
%@divi% "%numA%" "%numB%" "result"
echo @divi: %numA% / %numB% = %result%
echo.

::====================================================================
:: Note that a floating-point number can contain either a period or a comma
:: as the decimal mark.

echo ------ Testing Floating-Point Operations ------
set "numA=600700.58000040" & set "numB=30744568.79000250"
%@addf% "%numA%" "%numB%" "result"
echo @addf: %numA% + %numB% = %result%

set "numA=70512.5" & set "numB=-4000012.7244"
%@subf% "%numA%" "%numB%" "result"
echo @subf: %numA% - %numB% = %result%

:: Notice that both the inputs here have a comma but the result still
:: outputs the decimal mark as a period.
set "numA=-12945680,5600012" & set "numB=887402,5558"
%@multf% "%numA%" "%numB%" "result"
echo @multf: %numA% X %numB% = %result%

:: Change the default decimal mark output from a period to a comma.
%@setDeciMarkToComma%
echo @setDeciMarkToComma: Setting decimal mark output to comma.

:: Set the number of decimal places to store to a smaller size.
%@setDeciPlaces% "2"
echo @setDeciPlaces: Setting the maximum number of decimal places to 2.

:: The result here will only have two decimal digits and now
:: has a comma instead of a period.
set "numA=99095000.5120042" & set "numB=51.566782"
%@divf% "%numA%" "%numB%" "result"
echo @divf: %numA% / %numB% = %result%
%@setDeciMarkToPeriod%
echo @setDeciMarkToComma: Setting decimal mark output back to period.
%@setDeciPlaces% "16"
echo @setDeciPlaces: Setting the number of decimal places back to 16.
echo.

::====================================================================
echo ------ Testing Modulo Operations ------
set "numA=9840028322100042" & set "numB=34269102"
%@modi% "%numA%" "%numB%" "result"
echo @modi: %numA% %% %numB% = %result%

:: Note: Due to limitations in how the script handles division, the modulus of floats
:: is fairly limited in the size of the input numbers. Use with some caution.
set "numA=8351.05782572" & set "numB=231.02341"
%@modf% "%numA%" "%numB%" "result"
echo @modf: %numA% %% %numB% = %result%
echo.

::====================================================================
echo ------ Testing Random Operations ------
:: Use this if you need a random number between 0 and 9999999.
%@rand% "result"
echo @rand: Random number = %result%

:: If you need a random number between a specific range, then this should be used instead.
set "min=-2450050" & set "max=600105"
%@randr% "%min%" "%max%" "result"
echo @randr: Random number between %min% and %max% = %result%
echo.

::====================================================================
echo ------ Testing Trim Operation ------
:: In this example, the decimals in the float number are trimmed by retaining only the
:: first five digits (82779) and discarding the remaining six (109842).
set "num=42982.82779109842"
%@trimf% "%num%" "5" "result"
echo @trimf: %num% -^> %result%
echo.

::====================================================================
echo ------ Testing Rounding Operation ------
:: The decimal position starts at 0 (first 9 here).
set "num=127.93436995194"
%@roundf% "%num%" "7" "result"
echo @roundf: Rounded on the 7th decimal position (5): %num% -^> %result%
set "num=1959.758219002"

%@roundf% "%num%" "0" "result"
echo @roundf: Rounded to nearest integer (position 0): %num% -^> %result%
echo.
:: Note: To automatically round the outputs on all float operations, set the decimal
:: position using @setRoundPos (default is 16, no rounding).

::====================================================================
:: Like the standard arithmetic expressions, the batch compare operators can only
:: handle 32bit integers. The functions used here were created to overcome this 
:: limitation and allow the comparison of larger integer and floating-point numbers.
echo ------ Testing Compare Operations ------
set "numA=110002000078065543300" & set "numB=21044401662317"
%@compi% "%numA%" "LSS" "%numB%" "result"
if "%result%" equ "TRUE" (
  echo %numA% is less than %numB%
) else echo @compi: %numA% is not less than %numB%

set "numA=7800000356000003.534" & set "numB=7800000356000003.48508850001200"
%@compf% "%numA%" "GTR" "%numB%" "result"
if "%result%" equ "TRUE" (
  echo @compf: %numA% is greater than %numB%
) else echo %numA% is not greater than %numB%
echo.

::====================================================================
:: Use these to check if a number is within a specific range.

echo ------ Testing Range Operations ------
set "num=20548" & set "min=2130" & set "max=80970"
%@rangei% "%num%" "%min%" "%max%" "result"
if "%result%" equ "TRUE" (
  echo @rangei: %num% is within range of %min% and %max%
) else echo %num% is not within range of %min% and %max%

set "num=-1205001.12555" & set "min=-90028.5218" & set "max=9002080.24"
%@rangef% "%num%" "%min%" "%max%" "result"
if "%result%" equ "TRUE" (
  echo %num% is within range of %min% and %max%
) else echo @rangef: %num% is not within range of %min% and %max%
echo.

::====================================================================
echo ------ Testing Evaluation Operations ------
:: These functions will output "TRUE" if the number is valid or "FALSE" if it is not a 
:: proper number or is too large to be used in any of the script's functions. Note that if
:: the input is invalid, no internal error messages will be displayed to indicate the problem.

set "num=12345"
%@evali% "%num%" "result" && (
  echo @evali: "%num%" is a valid integer
) || echo "%num%" is not a valid integer

set "num=NOT_A_NUMBER"
%@evalf% "%num%" "result"
if "%result%" equ "TRUE" (
  echo "%num%" is a valid float
) else echo @evalf: "%num%" is not a valid float
echo.

::====================================================================
echo ------ Testing Operations with Error Handling ------
:: This disables internal error messages and can come in handy when you want
:: to display your own custom messages when dealing with user input.
%@disableErrorMes%
echo @disableErrorMes: Disabling internal error messages.

:: Disable pause on errors to display messages uninterrupted
%@disablePauseOnErrors%
echo @disablePauseOnErrors: Disabling pause on errors.

set "numA=NOT_A_NUMBER" & set "numB=123"
%@addi% "%numA%" "%numB%" "result" || echo An error has occurred: Invalid Input "%numA%"

:: Re-enable internal error messages. Any error message from now on will come from
:: the script itself.
%@enableErrorMes%
echo @enableErrorMes: Re-enabling internal error messages.

:: You can check the result variable to see if an operation failed.
set "numA=NOT_A_NUMBER" & set "numB=9999999999999999"
%@multi% "%numA%" "%numB%" "result"
if "%result%"=="ERROR" (
  REM *** An error was detected. Do something here? ***
)

:: As demonstrated in some of the previous examples, all functions will
:: return a error code so you can also use the '&&' and '||' conditional
:: symbols to catch and handle errors.
set "numA=999999" & set "numB=999"
%@compi% "%numA%" "NOT_A_OP" "%numB%" "result" && (
  :: If no errors were found, this code would have executed.
  if "!result!" equ "TRUE" (
    echo True - %numA% is equal to %numB%
  ) else echo False - %numA% is not equal to %numB%  
) || (
  REM Error detected. A message will be displayed and this part will execute.
)

echo.
pause
exit /b 0